config library

Classes

Config<T>
ConfigPath
Represents a config value path.
Configuration
PathConfig<T>
ValueConfig<T>

Enums

Environment

Exceptions / Errors

ConfigDeclarationException
Thrown when a Config itself is declared incorrectly, e.g. an enum typed config that does not provide the list of possible values.
ConfigException
ConfigFileException
Thrown when a config file cannot be read or does not contain a valid configuration.
ConfigPathException
ConfigReferenceException
Thrown when configuration references ($-syntax) form a cycle.
ConfigTypeException
ConfigValueException
Thrown when a config value is well typed but not one of the accepted values, e.g. an unknown name for an enum typed config.
InvalidConfigPathException
Thrown when a config path is not well formed, e.g. because one of its segments is empty.