- Available extensions
Properties
- address ↔ InternetAddress
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- port ↔ int
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connectHttp11(
{HttpAuth? auth, SecurityContext? securityContext, Duration? timeout}) → RestClient -
Available on Api, provided by the TestClient extension
-
connectHttp2(
{HttpAuth? auth, SecurityContext? securityContext, Duration? timeout}) → RestClient -
Available on Api, provided by the TestClient extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited