ApiEndpoint class abstract

Inheritance
Implementers

Constructors

ApiEndpoint({RouteMatcher matcher = const AnyRouteMatcher()})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
matcher RouteMatcher
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildRoutes() List<ApiRoute>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(ApiRequest request) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited