ApiMiddleware class abstract

Inheritance
Implementers

Constructors

ApiMiddleware({RouteMatcher matcher = const AnyRouteMatcher(), required List<ApiNode> routes, bool catchRequests = false})
const

Properties

catchRequests bool
final
hashCode int
The hash code for this object.
no setterinherited
matcher RouteMatcher
finalinherited
routes List<ApiNode>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildRoutes() List<ApiRoute>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(ApiRequest request, RequestHandler<ApiResponse> next) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited