ApiRequestException class
An exception that can explicitly be transformed into an ApiResponse using toResponse.
- Inheritance
-
- Object
- ApiException
- ApiRequestException
- Implementers
Constructors
-
ApiRequestException(int statusCode, String? message, {Map<
String, dynamic> ? data}) - ApiRequestException.badRequest([String? message])
- ApiRequestException.forbidden([String? message])
-
ApiRequestException.fromResponse(int statusCode, Map<
String, dynamic> data) - ApiRequestException.internalError([String? message])
- ApiRequestException.methodNotAllowed([String? message])
- ApiRequestException.notFound([String? message])
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toResponse(
) → ApiResponse -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited