ConfigDeclarationException class

Thrown when a Config itself is declared incorrectly, e.g. an enum typed config that does not provide the list of possible values.

This indicates a mistake in the application code rather than in the configuration that was supplied at runtime.

Inheritance

Constructors

ConfigDeclarationException(String path, String message)

Properties

hashCode int
The hash code for this object.
no setterinherited
internal → dynamic
finalinherited
message String
finalinherited
path String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited