DataField<Data, FieldType> class

Implemented types
Available extensions

Constructors

DataField({required String name, required FieldType valueOf(Data), required Encoder<FieldType> toJson, required Decoder<FieldType> fromJson, DataBean<DataObject> dataBean()?, List<MetaData> meta = const [], List<DataFieldConstraint> constraints = const []})

Properties

constraints List<DataFieldConstraint>
final
dataBean DataBean<DataObject>?
latefinal
dataType → TypeCheck<Data>
no setter
hashCode int
The hash code for this object.
no setterinherited
meta List<MetaData>
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → TypeCheck<FieldType>
no setter

Methods

allMetaOfType<M extends MetaData>([bool test(M)?]) Iterable<M>
asc() Sort

Available on Expression, provided by the ExpressionFilterExtension extension

Creates a Sort that orders ascending by this expression.
checkConstraints(FieldType value) List<DataFieldConstraint>
Validates constraints and returns a list of constraints that are violated.
constraintOfType<T extends DataFieldConstraint>([bool test(T)?]) → T?
contains(dynamic other) Filter

Available on Expression, provided by the ExpressionFilterExtension extension

Convenience method for creating a CompareFilter which matches if this contains other.
desc() Sort

Available on Expression, provided by the ExpressionFilterExtension extension

Creates a Sort that orders descending by this expression.
equals(dynamic other) Filter

Available on Expression, provided by the ExpressionFilterExtension extension

Convenience method for creating a CompareFilter which matches if this equals other.
fromJson(dynamic object, {String? name}) → FieldType
greaterOrEqual(dynamic other) Filter

Available on Expression, provided by the ExpressionFilterExtension extension

Convenience method for creating a CompareFilter which matches if this is greater than or equals other.
greaterThan(dynamic other) Filter

Available on Expression, provided by the ExpressionFilterExtension extension

Convenience method for creating a CompareFilter which matches if this is greater than other.
hasConstraintOfType<T extends DataFieldConstraint>([bool test(T)?]) bool
hasMetaOfType<M extends MetaData>([bool test(M)?]) bool
isIn(dynamic other) Filter

Available on Expression, provided by the ExpressionFilterExtension extension

Convenience method for creating a CompareFilter which matches if this is in other.
lessOrEqual(dynamic other) Filter

Available on Expression, provided by the ExpressionFilterExtension extension

Convenience method for creating a CompareFilter which matches if this is less than or equals other.
lessThan(dynamic other) Filter

Available on Expression, provided by the ExpressionFilterExtension extension

Convenience method for creating a CompareFilter which matches if this is less than other.
metaOfType<M extends MetaData>([bool test(M)?]) → M?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(dynamic other) Filter

Available on Expression, provided by the ExpressionFilterExtension extension

Convenience method for creating a CompareFilter which matches if this does not equal other.
sort(bool ascending) Sort

Available on Expression, provided by the ExpressionFilterExtension extension

Creates a Sort that orders by this expression.
toJson(FieldType object) → dynamic
toString() String
A string representation of this object.
inherited
valueOf(Data object) → FieldType

Operators

operator ==(Object other) bool
The equality operator.
inherited