Filter class sealed

Representing filter arguments in a uniform, abstract way.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(Filter other) Filter
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
or(Filter other) Filter
reduce() Filter
Tries to simplify the Filter structure to avoid redundancy.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

andGroup(Iterable<Filter> filters) Filter
Returns the smallest representation of the "And" group of filters.
equals(dynamic left, dynamic right) CompareFilter
Convenience method for creating a CompareFilter filter with compare type CompareType.equals.
notEquals(dynamic left, dynamic right) CompareFilter
Convenience method for creating a CompareFilter filter with compare type CompareType.notEquals.
orGroup(Iterable<Filter> filters) Filter
Returns the smallest representation of the "Or" group of filters.

Constants

empty → const Filter