FilterGroup class final

Joins multiple Filter elements into a group using a FilterGroupType.

Best practice: Use the convenience methods Filter.and / Filter.or instead of instantiating FilterGroup directly.

Inheritance

Constructors

FilterGroup(List<Filter> filters, bool isConjunction)
const

Properties

filters List<Filter>
final
hashCode int
The hash code for this object.
no setterinherited
isConjunction bool
final
isEmpty bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

and(Filter other) Filter
inherited
matches(DataObject object) bool
Evaluates this filter against object and returns whether it matches.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
or(Filter other) Filter
inherited
reduce() Filter
Returns the smallest representation of this filter.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited