GeometryTypeConstraint<FieldType extends Geometry?> class

Inheritance

Constructors

GeometryTypeConstraint({required GeometryType type, String name = 'default.geometry-type'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type GeometryType
final

Methods

check(FieldType value) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited