MaxLengthConstraint<FieldType extends String?> class

Inheritance

Constructors

MaxLengthConstraint({required int length, String name = 'default.max-length'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
final
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

check(FieldType value) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited