MultiLineString class

Inheritance

Constructors

MultiLineString(int? srid, List<LineString> lineStrings, bool hasZ, bool hasM)
const
MultiLineString.read(int? srid, ByteDataReader reader, bool hasZ, bool hasM)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
hasM bool
finalinherited
hasZ bool
finalinherited
lineStrings List<LineString>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
srid int?
finalinherited
type GeometryType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes(ByteOrder byteOrder) Uint8List
override
toEWKB({ByteOrder byteOrder = ByteOrder.wkbNDR}) Uint8List
The extended WKB representation, which adds the srid to the type.
inherited
toString() String
A string representation of this object.
override
toText() String
toWKB(ByteOrder byteOrder) Uint8List
The plain WKB representation, which is how this geometry is written as a member of a multi geometry or a collection: only the geometry containing it carries an SRID.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override