NamingConvention enum

Inheritance
Available extensions

Values

none → const NamingConvention

no formatting applied

lowerSnakeCase → const NamingConvention

lower snake case => lower_snake_case

upperSnakeCase → const NamingConvention

upper snake case => UPPER_SNAKE_CASE

camelCase → const NamingConvention

camel case => CamelCase

lowerCamelCase → const NamingConvention

lower camel case => lowerCamelCase

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NamingConvention>
A constant List of the values in this enum, in order of their declaration.