ResourceEndpoint class
- Inheritance
-
- Object
- ApiRoute
- ApiEndpoint
- ResourceEndpoint
Constructors
- ResourceEndpoint({RouteMatcher matcher = const AnyRouteMatcher(), RequestHandler? get, RequestHandler? post, RequestHandler? patch, RequestHandler? put, RequestHandler? delete, RequestHandler? options, RequestHandler? head})
-
const
Properties
- delete → RequestHandler?
-
final
- get → RequestHandler?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- head → RequestHandler?
-
final
- matcher → RouteMatcher
-
finalinherited
- options → RequestHandler?
-
final
- patch → RequestHandler?
-
final
- post → RequestHandler?
-
final
- put → RequestHandler?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildRoutes(
) → List< ApiRoute> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onRequest(
ApiRequest request) → Future -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited