Tracer class

Constructors

Tracer({required String name, required String? version, required bool enableDartTimeline, required Map<String, dynamic> attributes, required Sink<Span> sink})

Properties

attributes Map<String, dynamic>
final
enableDartTimeline bool
final
hashCode int
The hash code for this object.
no setterinherited
key String
latefinal
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
final

Methods

findParentSpan() Span?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remoteSpan<R>(TraceId traceId, SpanId spanId, FutureOr<R> delegate()) FutureOr<R>
runInSpanZone<R>(LocalSpan span, FutureOr<R> delegate(LocalSpan span)) Future<R>
startSpan(String name, Map<String, dynamic>? attributes, {SpanType? type}) LocalSpan
toString() String
A string representation of this object.
inherited
trace<R>(String name, Map<String, dynamic>? attributes, SpanType? type, FutureOr<R> delegate(LocalSpan span)) Future<R>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildKey(String name, String? version) String