UpgradeHttpResponse class

HttpResponse for hijacking the underlying socket. Use for protocols that upgrade from HTTP (like websocket).

Inheritance

Constructors

UpgradeHttpResponse(Uri requestUrl, Map<String, List<String>> headers, void socketHandler(Socket))

Properties

bodyData Stream<List<int>>
finalinherited
charset Encoding?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, List<String>>
finalinherited
requestUrl Uri
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socketHandler → void Function(Socket)
final
statusCode int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited