ComposeEnvironment class

Constructors

ComposeEnvironment({required String compose})
const
ComposeEnvironment.fromFile(String path)

Properties

compose String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findPort(String projectId, String service, int containerPort) Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
up() Future<ComposeEnvironmentInstance>

Operators

operator ==(Object other) bool
The equality operator.
inherited