ComposeEnvironmentInstance class

Constructors

ComposeEnvironmentInstance({required ComposeEnvironment composeEnvironment, required String projectId, required List<ServicePort> servicePorts})

Properties

composeEnvironment ComposeEnvironment
final
hashCode int
The hash code for this object.
no setterinherited
projectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servicePorts List<ServicePort>
final

Methods

buildConfiguration({List<(String, String)>? remap}) Map<String, dynamic>
down() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited