ServiceDelegate class
- Implemented types
Constructors
-
ServiceDelegate({Future<
void> initialize()?, Future<void> dispose()?, Future<void> postInitialize()?})
Properties
-
dispose
→ Future<
void> Function()? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialize
→ Future<
void> Function()? -
final
-
postInitialize
→ Future<
void> Function()? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createInstance(
) → ServiceInstance< ServiceDelegate> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited