ServicePort class
Constructors
- ServicePort({required String name, required int containerPort, required int hostPort})
-
const
Properties
- containerPort → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostPort → int
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited