- Mixed-in types
- Implementers
Properties
-
$$fields
→ List<
DataField< OidcResponse, dynamic> > -
no setteroverride
- $$name → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? accessToken, String? tokenType, int? expiresIn, String? scope, bool nullScope = false, String? refreshToken, bool nullRefreshToken = false, String? idToken, bool nullIdToken = false}) → OidcResponse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
$accessToken
→ DataField<
OidcResponse, String> -
final
-
$expiresIn
→ DataField<
OidcResponse, int> -
final
-
$idToken
→ DataField<
OidcResponse, String?> -
final
-
$refreshToken
→ DataField<
OidcResponse, String?> -
final
-
$scope
→ DataField<
OidcResponse, String?> -
final
-
$tokenType
→ DataField<
OidcResponse, String> -
final
-
bean
→ DataBean<
OidcResponse> -
final
Static Methods
-
fromJson(
dynamic data, {String? name}) → OidcResponse -
fromValues(
Map< String, dynamic> data) → OidcResponse
Constants
- $$codec → const JsonDataCodec