AuthenticationMiddleware<T extends Session> class
abstract
- Inheritance
-
- Object
- ApiRoute
- ApiMiddleware
- AuthenticationMiddleware
- Implementers
Constructors
-
AuthenticationMiddleware({RouteMatcher matcher = const AnyRouteMatcher(), required List<
ApiNode> routes, bool catchRequests = false, bool requireSession = true}) -
const
Properties
- catchRequests → bool
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- matcher → RouteMatcher
-
finalinherited
- requireSession → bool
-
final
-
routes
→ List<
ApiNode> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
ApiRequest request) → Future< T?> -
buildRoutes(
) → List< ApiRoute> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onRequest(
ApiRequest request, RequestHandler< ApiResponse> next) → Future -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited