ConfigDeclarationException class
Thrown when a Config itself is declared incorrectly, e.g. an enum typed config that does not provide the list of possible values.
This indicates a mistake in the application code rather than in the configuration that was supplied at runtime.
- Inheritance
-
- Object
- ApiException
- ConfigException
- ConfigDeclarationException
Constructors
- ConfigDeclarationException(String path, String message)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited