matches method
Evaluates this filter against object and returns whether it matches.
This provides in-memory filter evaluation with semantics matching the PostgreSQL implementation:
- String
contains/isInuse case-insensitive regex matching - List
containschecks element membership - null comparisons use
== null/!= nullsemantics
Implementation
@override
bool matches(DataObject object) => isConjunction
? filters.every((f) => f.matches(object))
// A group without operands is unconstrained, consistent with [isEmpty].
: filters.isEmpty || filters.any((f) => f.matches(object));