WebsocketFrameDecoder class
- Inheritance
-
- Object
- StreamTransformerBase<
Uint8List, WebsocketFrame> - WebsocketFrameDecoder
Constructors
- WebsocketFrameDecoder({int maxFrameSize = defaultMaxFrameSize, bool requireMask = true})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxFrameSize → int
-
Maximum accepted payload size of a single frame. Larger frames fail
the connection with close code 1009 (message too big).
final
- requireMask → bool
-
Whether frames are required to be masked (RFC 6455 section 5.1
requires this for client-to-server frames).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(
Stream< Uint8List> stream) → Stream<WebsocketFrame> -
Transforms the provided
stream.override -
cast<
RS, RT> () → StreamTransformer< RS, RT> -
Provides a
StreamTransformer<RS, RT>view of this stream transformer.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultMaxFrameSize → const int
- 16 MiB